<?php
/**
 * @file
 * Contains the list style plugin.
 */

/**
 * This style plugin is used to show a Views Bulk Operations but to respect the group
 * hierarchy.
 *
 * @ingroup views_style_plugins
 */
class views_hierarchy_operations_plugin_style extends views_bulk_operations_plugin_style {

  /**
   * Set default options
   */
  function option_definition() {
    $options = parent::option_definition();

    $options['main_field'] = array('default' => '');
    $options['parent_field'] = array('default' => '');

    return $options;
  }

  /**
   * Render the given style.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    watchdog(WATCHDOG_DEBUG, __FILE .': '. __LINE__);
    $fields = array('' => t('<None>'));

    foreach ($this->display->handler->get_handlers('field') as $field => $handler) {
      if ($label = $handler->label()) {
        $fields[$field] = $label;
      }
      else {
        $fields[$field] = $handler->ui_name();
      }
    }

    $events = array('click' => t('On Click'), 'mouseover' => t('On Mouseover'));

    $form['type']['#description'] = t('Whether to use an ordered or unordered list for the retrieved items. Most use cases will prefer Unordered.');

    $form['main_field'] = array(
      '#type' => 'select',
      '#title' => t('Main field'),
      '#options' => $fields,
      '#default_value' => $this->options['main_field'],
      '#description' => t('Select the field with the unique identifier for each record.'),
      '#required' => TRUE,
    );

    $form['parent_field'] = array(
      '#type' => 'select',
      '#title' => t('Parent field'),
      '#options' => $fields,
      '#default_value' => $this->options['parent_field'],
      '#description' => t('Select the field that contains the unique identifier of the record\'s parent.'),
    );
  }

  function render() {

    // Get the fields.
    $fields = views_hierarchy_operations_get_fields(array('#view' => $this->view));

    // Normalize this to a result tree first, unless someone else did it for us.
    if (!isset($this->view->result_tree)) {

      // Use the ResultTree library.
      $tree = new ResultTree($this->view->result, $fields['#main_field'], $fields['#parent_field']);
      $this->view->result_tree = $tree->getTree();
      $this->view->result = $tree->getFlat();
    }

    // We build the groups here to pass them to the node_selector function through the form.
    $sets = $this->render_grouping($this->view->result, $this->options['grouping']);
    $this->sets = $sets;

    // Invoke a hook to let other modules do something.
    module_invoke_all('views_hierarchy_operations_render', $this->view);

    // Append suffix to avoid clashing between multiple VBOs on same page.
    static $form_suffix;
    if (isset($form_suffix)) {
      $form_suffix++;
    }
    else {
      $form_suffix = 1;
    }
    return drupal_get_form('views_hierarchy_operations_form__' . $form_suffix, $this);
  }
}
